@@ -47,22 +47,38 @@
 // for osm-gps-map:
 #define USE_CAIRO
 #define ENABLE_OSD
-#define ENABLE_BALLOON
+#define OSD_BALLOON
+#define OSD_SCALE
+#define OSD_CROSSHAIR
 
 #ifdef USE_MAEMO
 #define BIG_BALLOONS
 #define BALLOON_AREA_WIDTH       380
 #define BALLOON_AREA_HEIGHT      100
 #define BALLOON_CORNER_RADIUS     20
+#define OSD_FONT_SIZE             28
+#define OSD_DIAMETER              60
+#define OSD_SCALE_FONT_SIZE       20
+#define OSD_CROSSHAIR_RADIUS      20
+#define OSD_COORDINATES_FONT_SIZE 20
+
+/* limit screen refresh while dragging to avoid delays */
+#define OSM_GPS_MAP_REFRESH  25
 #endif
 
+#define OSD_COORDINATES
+#include <libintl.h>
+#define OSD_COORDINATES_CHR_N  gettext("N")
+#define OSD_COORDINATES_CHR_S  gettext("S")
+#define OSD_COORDINATES_CHR_E  gettext("E")
+#define OSD_COORDINATES_CHR_W  gettext("W")
+
 /* only maemo devices up to version 4 have a fullscreen button */
 #ifdef USE_MAEMO
 #include <hildon/hildon-defines.h>
 #if (MAEMO_VERSION_MAJOR < 5)
 #define OSM_GPS_MAP_KEY_FULLSCREEN  HILDON_HARDKEY_FULLSCREEN
 #else
-#define OSD_FONT_SIZE               28
 #define OSM_GPS_MAP_KEY_FULLSCREEN  'f'
 #endif
 #define OSM_GPS_MAP_KEY_ZOOMIN      HILDON_HARDKEY_INCREASE
@@ -78,12 +94,6 @@
 #define OSM_GPS_MAP_KEY_LEFT        GDK_Left
 #define OSM_GPS_MAP_KEY_RIGHT       GDK_Right
 
-#ifdef USE_MAEMO
-/* limit screen refresh while dragging to avoid delays */
-#define OSM_GPS_MAP_REFRESH  25
-#define OSD_DIAMETER         60
-#endif
-
 /* specify OSD colors explicitely. Otherwise gtk default */
 /* colors are used. fremantle always uses gtk defaults */
 #if !defined(USE_MAEMO) || (MAEMO_VERSION_MAJOR < 5)
