@@ -217,7 +217,6 @@ void gconf_load_state(appdata_t *appdata) {
     char str[128];
     snprintf(str, sizeof(str), GCONF_KEY_GPX, i);
     char *fname = gconf_client_get_string(appdata->gconf_client, str, NULL);
-
     if(fname) {
       /* check if there's a valid name stored for this file. */
       /* if yes it's a "closed" file */
@@ -237,16 +236,21 @@ void gconf_load_state(appdata_t *appdata) {
 	  /* restoring the gpx file failed, mark it as unusable, but save */
 	  /* its presence for later use */
 	  
-	  /* create fake entry to remember this file for next load attempt */
+	  /* create "closed" entry to remember this file for next */
+	  /* load attempt */
 	  *gpx = g_new0(gpx_t, 1);
 	  (*gpx)->filename = fname;
-	  (*gpx)->failed = TRUE;
+	  char *p = fname;
+	  if(strrchr(fname, '/'))
+	    p = strrchr(fname, '/')+1;
+
+	  (*gpx)->name = g_strdup_printf(_("Failed to load: %s"), p);
+	  (*gpx)->closed = TRUE;
 	} else
 	  free(fname);
       }
+      gpx = &((*gpx)->next);
     }
-
-    gpx = &((*gpx)->next);
   }
 
   gpx_busy_dialog_destroy(dialog);
