@@ -360,27 +360,31 @@ static gboolean skip_element(xmlTextReaderPtr reader) {
 
 static char *process_text(xmlTextReaderPtr reader) {
   char *text = NULL;
-  int depth = xmlTextReaderDepth(reader);
-  int ret = xmlTextReaderRead(reader);
-  while((ret == 1) && 
-	((xmlTextReaderNodeType(reader) != XML_READER_TYPE_END_ELEMENT) ||
-	 (xmlTextReaderDepth(reader) != depth))) {
 
-    /* found a text fragment */
-    if((xmlTextReaderNodeType(reader) == XML_READER_TYPE_TEXT) ||
-       (xmlTextReaderNodeType(reader) == XML_READER_TYPE_CDATA)) {
-      char *frag = (char*)xmlTextReaderConstValue(reader);
+  if(!xmlTextReaderIsEmptyElement(reader)) {
 
-      if(!text) text = strdup(frag);
-      else {
-	char *old = text;
-	text = malloc(strlen(old) + strlen(frag) + 1);
-	strcpy(text, old);
-	strcat(text, frag);
-	free(old);
+    int depth = xmlTextReaderDepth(reader);
+    int ret = xmlTextReaderRead(reader);
+    while((ret == 1) && 
+	  ((xmlTextReaderNodeType(reader) != XML_READER_TYPE_END_ELEMENT) ||
+	   (xmlTextReaderDepth(reader) != depth))) {
+      
+      /* found a text fragment */
+      if((xmlTextReaderNodeType(reader) == XML_READER_TYPE_TEXT) ||
+	 (xmlTextReaderNodeType(reader) == XML_READER_TYPE_CDATA)) {
+	char *frag = (char*)xmlTextReaderConstValue(reader);
+	
+	if(!text) text = strdup(frag);
+	else {
+	  char *old = text;
+	  text = malloc(strlen(old) + strlen(frag) + 1);
+	  strcpy(text, old);
+	  strcat(text, frag);
+	  free(old);
+	}
       }
+      ret = xmlTextReaderRead(reader);
     }
-    ret = xmlTextReaderRead(reader);
   }
 
   return text;
@@ -664,6 +668,7 @@ static void process_gpx_wpt_gc(xmlTextReaderPtr reader, cache_t *cache) {
 		  (strcasecmp(name, "hints") == 0))	{
 	  if(!cache->hint) {
 	    cache->hint = process_text(reader);
+
 	    /* often hints aren't more than just a bunch of blanks ... */
 	    if(cache->hint && all_is_white(cache->hint)) {
 	      free(cache->hint);
