@@ -138,40 +138,50 @@ gpx_t *choose_file(appdata_t *appdata, gboolean whole_dir) {
   gtk_widget_show_all (GTK_WIDGET(dialog));
   if (gtk_dialog_run (GTK_DIALOG(dialog)) == GTK_FM_OK) {
     char *filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+    
+    if(filename) {
+      gpx_dialog_t *dialog = gpx_busy_dialog_new(GTK_WIDGET(appdata->window));
 
-    gpx_dialog_t *dialog = gpx_busy_dialog_new(GTK_WIDGET(appdata->window));
-
-    if(!whole_dir) 
-      gpx = gpx_parse(dialog, filename);
-    else {
-      /* cur trailing '/' if present */
-      if(strlastchr(filename) == '/')
-	filename[strlen(filename)] = 0;
-
-      gpx = gpx_parse_dir(dialog, filename);
-    }
-
-    gpx_busy_dialog_destroy(dialog);
-
-    /* save path if gpx was successfully loaded */
-    if(gpx) {
-      char *r = strrchr(filename, '/');
-
-      /* there is a delimiter, use everything left of it as path */
-      if(r && !whole_dir) {
-	*r = 0;
-	if(appdata->path) free(appdata->path);
-	appdata->path = strdup(filename);
-	/* restore path ... just in case ... */
-	*r = '/';
+      if(!whole_dir) 
+	gpx = gpx_parse(dialog, filename);
+      else {
+	/* cur trailing '/' if present */
+	if(strlastchr(filename) == '/')
+	  filename[strlen(filename)] = 0;
+	
+	gpx = gpx_parse_dir(dialog, filename);
       }
+      
+      gpx_busy_dialog_destroy(dialog);
+      
+      /* save path if gpx was successfully loaded */
+      if(gpx) {
+	char *r = strrchr(filename, '/');
+	
+	/* there is a delimiter, use everything left of it as path */
+	if(r && !whole_dir) {
+	  *r = 0;
+	  if(appdata->path) free(appdata->path);
+	  appdata->path = strdup(filename);
+	  /* restore path ... just in case ... */
+	  *r = '/';
+	}
+	
+	if(whole_dir)
+	  appdata->path = strdup(filename);
+      } else
+	errorf(_("Load error"));
 
-      if(whole_dir)
-	appdata->path = strdup(filename);
-    } else
-      errorf(_("Load error"));
-
-    g_free (filename);
+      g_free (filename);
+    } else {
+#ifndef USE_MAEMO
+      errorf(_("Error accessing the file."));
+#else
+      errorf(_("Error accessing the file. This may happen if the file "
+	       "resides on a remote file system. Please copy the file onto "
+	       "the device (e.g. onto the memory card) and try again."));
+#endif
+    }
   }
   
   gtk_widget_destroy (dialog);
@@ -967,16 +977,13 @@ static GtkWidget *gpxlist_create_view_and_model(appdata_t *appdata,
   GtkTreeIter sel_iter;
   gboolean sel_iter_valid = FALSE;
   while(gpx) {
-    /* don't display entries that failed at load */
-    if(!gpx->failed) {
-      GtkTreeIter         iter;
-      gtk_list_store_append(appdata->gpxstore, &iter);
-      gpxlist_set(appdata->gpxstore, &iter, gpx);
-      
-      if(gpx == sel_gpx) {
-	sel_iter = iter;
-	sel_iter_valid = TRUE;
-      }
+    GtkTreeIter         iter;
+    gtk_list_store_append(appdata->gpxstore, &iter);
+    gpxlist_set(appdata->gpxstore, &iter, gpx);
+    
+    if(gpx == sel_gpx) {
+      sel_iter = iter;
+      sel_iter_valid = TRUE;
     }
 
     gpx = gpx->next;
